@@ -155,6 +155,8 @@ struct Ctx {
 
     can_inline_arguments: bool,
 
+    is_nested_if_return_merging: bool,
+
     /// Current scope.
     scope: SyntaxContext,
 }
@@ -289,6 +291,8 @@ impl Optimizer<'_> {
 
         self.reorder_stmts(stmts);
 
+        self.merge_sequences_in_stmts(stmts);
+
         self.merge_simillar_ifs(stmts);
         self.join_vars(stmts);
 
@@ -2202,8 +2206,6 @@ impl VisitMut for Optimizer<'_> {
 
         self.with_ctx(ctx).inject_else(stmts);
 
-        self.with_ctx(ctx).merge_sequences_in_stmts(stmts);
-
         self.with_ctx(ctx).handle_stmt_likes(stmts);
 
         self.with_ctx(ctx).merge_var_decls(stmts);
